bibliotheca Augustana

<<< Übersicht <<< vorige Seite nächste Seite >>>
BIBLIOTHECA AUGUSTANA

Das Nibelungenlied

1190/1200

| # Handschrift B ## 7. Aventiure
___________________________________________________
| ### <S> was ir sciff gegan ### der bvrge also nahen do sah der kvnec stan ### oben in den venstern vil manege scoene meit ### daz er ir niht erchande daz was Gvnthere leit ### Er vragte Sivride den gesellen sin ### ist iv daz iht chvende vmb disiv magedin ### di dort her nider scovwent gein vns vf di flvot ### swi ir herre heize si sint vil hohe gemvot
###### 389 | ### <· o> sprach der herre Sivrit nv svlt ir tovgen spehn ### vnder den ivnchfrovwen vn– svlt mir danne iehn ### welhe ir nemen woldet hetet irs gewalt ### daz tvon ich so sprach Gvnther ein riter chven vn– balt
###### 390 | ### So sihe ich ir eine in ienem venster stan ### in snê wizer wæte div ist so wolgetan ### di welent miniv ovgen dvrch ir scoenen lip ### ob ich gewalt des hete si mvese werden min wip
| ### <Dir> hat erwelt vil rehte diner ovgen shin ### ez ist div edel Prvnhilt daz shone magdin ### nach der din herce ringet der sin vnt ovch der mvt ### elliv ir gebærde div dvhte gvntheren gvt
| ### Do hiez div kvneginne vz den venstern gan ### ir herliche mægde sin solden da niht stan ### den vremden an ce sehene des waren si bereit ### waz do di vrowen taten daz ist vns sider <ovch> geseit
###### 393 | ### Gegen den vnchvnden strichen si ir lip ### des ie site heten div wetlichen wip ### an div engen venster chomen si gegan ### da si <di> helde sahen daz wart dvrch schowen getan
###### 394 | ### Ir waren niwan viere di chomen in daz lant ### Sifrit der chvone ein ros zoch vf den sant ### da sahen dvrch venster div wætlichen wip ### des dvhte sich getiwert des kvnech Gvntheres lip
###### 395 | ### Er habt im da bi zovme di zierlichen march ### gvot vnt schone vil michel vnt [308a] vil starch ### vnz der chvnich Gvnther in den satel gesaz ### also diente im Sifrit deser doch sit vil gar vergaz
###### 396 | ### Do zoch er ovch daz sine von dem schiffe dan ### er het solhen dienest vil selten ê getan ### daz er bi stegereife gestvnde helde mer ### daz sahen dvrch div venster di vrowen schon vnt her
###### 397 | ### Reht in einer maze den helden vil gemeit ### von sne blancher varwe ir ros vnt ovch ir chleit ### waren vil geliche ir schilde wol getan ### di lvhten von den handen den vil wætlichen man
###### 398 | ### Ir setel wol gesteinet ir fvrbvge smal ### si riten herliche fvr prvnhilde sal ### dar an hiengen schellen von liehtem golde rot ### si chomen zv dem lande als ez ir ellen gebot
###### 399 | ### Mit spern niwe sliffen mit swerten wol getan ### div vf di sporn giengen den wætlichen man ### di fvrten di vil chvnen scharpf vnt breit ### daz sach alliz prvnhilt div vil herliche meit
###### 400 | ### Mit in chomen do Danchwart vnt ovch hagene ### wir horen sagen mære wi di degene ### von raben swarcer varwe trvogen richiv chleit ### ir schilde waren schone michel gvt vnt breit
###### 401 | ### Von india dem lande man sah si steine tragen ### do chos man an ir wete vil herliche wagen ### si liezen ane hvte ir schiffel bi der flvot ### svs riten zv der bvrge di helde chvne vnt gvt
###### 402 | ### Sehs vnt ahzech tvrne si sahen drinne stan ### dri palas wite vnt einen sal wol getan ### von edelem marmelsteine grvne alsam ein gras ### dar inne selbe prvnhilt mit <ir> ingesinde was
###### 403 | ### Div bvrch was entslozzen vil wite vf getan ### do lieffen in engegene di prvnhilde man ### vnt enpfiengen dise geste in ir vrowen lant ### ir ros hiez man behalten vnt ir schilde von der hant
###### 404 | ### Do sprach ein chamerære ir svlt vns geben div swert ### vnt ovch di liehten brvnne des sit ir vngewert ### sprach von Tronge hagene wir wellens selbe tragen ### do begonde im Sifrit da von div rehten mere sagen
###### 405 | ### Man pfliget in dirre bvrge <daz> wil ich iv sagen ### daz neheine geste hie waffen svlen tragen ### nv lat si tragen hinnen daz ist wol getan ### des volgete vil vngerne hagen Gvntheres man
###### 406 | ### Man hiez den gesten schenchen vnt shvf in gemach ### vil manigen snellen rechen man da cehove sach ### in fvrstlicher wæte allenthalben gan ### do wart vil michel schowen [308b] an di chvnen getan
| ### Do wart vrowen prvnhilde gesaget mit <mæren> ### daz vnchvnde rechen da chomen wæren ### in herlicher wæte gevlozen vf dem flvt ### da von begonde vragen div magt shone vnt gvt
###### 408 | ### Ir svlt mich lazzen horen sprach div chvnegin ### wer di vil vnchvnden rechen mvgen sin ### di in miner bvrge so herliche stan ### vnt dvrch welhes liebe di helde her gevarn han
| ### Do sprach ein ir gesinde vrowe ich mach wol iehen ### daz ich ir deheinen nie mer habe gesehen ### want geliche sifride einer darvnder stat ### den svlt ir wol enpfahen daz ist mit triwen min rat
###### 410 | ### <Der> ander der gesellen der ist so lobelich ### op er gewalt des hete wol wær er ein chvnich rich ### op witen fvrsten landen vnd maht er div gehan ### man siht in bi den andern so rehte herliche stan
###### 411 | ### <Der> dritte der gesellen der ist so grivlich ### vnt doch mit schonem libe chvneginne rich ### von swinden sinen blichen der er so vil getvt ### er ist in sinen sinnen ich wæne grimme gemvt
###### 412 | ### Der ivngeste dar vnder der ist so lobelich ### magtlicher zvohte sihe ich den degen rich ### mit gvotem gelezze so minnechliche stan ### wir mohtenz alle fvrhten hete im hi iemen iht getan
###### 413 | ### Swi plide er pflege der zvhte vnd swi shone si sin lip ### er mohte wol er weinen vil wætlichiv wip ### swenner begonde zvrnen sin lip ist so gestalt ### er ist in allen tvgenden ein degen chvne vnd balt
| ### Do sprach div chvneginne nv brinch mir gewant ### vnt ist der starche Sifrit chomen in diz lant ### dvrch willen miner minne ez gat im an den lip ### ich fvrhte <in> niht so sere daz ich werde sin wip
###### 415 | ### Prvnnhilt div schone wart schiere wol gechleit ### do giench mit ir dannen vil manich schoniv meit ### wol hvndert oder mere geciert was ir lip ### ez wolden sehen di geste div vil wætlichen wip
###### 416 | ### <da> mit giengen degene da vz is Lant ### di Prvnnhilde rechen di trvgen swert enhant ### fvmpf hvndert oder mere daz was den gesten leit ### do stvnden von dem sædele di helde chvne vnt gemeit
| ### Do div chvneginne Sifriden sach ### nv mvget ir gerne horen wi div magt sprah ### sit wille chomen Sifrit <her> in diz lant ### waz meinet iwer reise gerne het ich daz be [309a] chant
###### 418 | ### Vil michel iwer genade min vrov Prvnnhilt ### daz ir mich gervchet grvzen fvrsten tohter milt ### vor disem edelen rechen der hie vor mir stat ### wand er ist min herre der eren het ich gerne rat
| ### Er ist geborn von rine waz sol ich dir sagen mer ### dvrch di dine liebe sin wir gevarn her ### der wil dich gerne minnen swaz im da von geschit ### nv bedenches dich bezite min herre er lazet dich es niht
###### 420 | ### Er ist geheizen Gvnther vnt ist ein chvnich her ### er wrbe er dine minne ern gerte nihtes mer ### ia gebot mir her ce varne der reche wol getan ### moht ich es im geweigert han ich het iz gerne ver lan
| ### Si sprach ist er din herre vnt bistv sin man ### div spil div ich im teile getar er div bestan ### behabt er des meisterschapft so wird ich sin wip ### vnt ist daz ich gewinne ez get iv allen an den lip
###### 422 | ### Do sprach von Tronege Hagene frowe lat vns sehen ### iweriv spil div starchen. ê daz iv mvste iehen ### Gvnther min herre da mvst iz herte sin ### er trwet wol erwerben ein also schone magedin
###### 423 | ### Den stein schol er werffen vnt springen dar nach ### den gere mit mir shiezen lat iv sin niht ce gach ### ir mvget wol hie verliesen di ere vnd ovch den lip ### des bedenchet ivch vil ebene sprach daz minnechliche wip
###### 424 | ### Sifrit der vil chvne zv dem kvonege trat ### allen sinen willen er in reden bat ### gegen der chvneginne er solde an angest sin ### ich sol ivch wol behivten vor ir mit den listen min
###### 425 | ### Do sprach der chvnech Gvnther chvneginne her ### nv teilet swaz ir gebietet vnt wæres dannoch mer ### daz bestvnde ich allez dvrch iwern schonen lip ### min hovbet wil ich verliesen irn werdet min wip
| ### Do div chvneginne sine rede vernam ### des spils bat si gahen als ir do gezam ### si hiez ir gewinnen ce strite gvt gewant ### eine prvnne rotes goldes vnt einen gvoten schildes rant
###### 427 | ### Ein waffen hemde siden daz leit an div meit ### daz in deheinem strite waffen nie versneit ### von pfellel vzer lybia ez was vil wol getan ### von porten lieht gewrhte sach man schinen dar an
###### 428 | ### Di zit wart disen rechen mit gelfe vil gedrevt ### Danchwart vnt Hagene di [309b] waren vngefrevt ### wi iz dem chvnege ergienge des sorgete in der mvt ### si dahten vnser reise div ist vns rechen niht ce gvt
| ### Di wile was ovch Sifrit der wætliche man ### ê iz iemen erfvnde in daz schif gegan ### da er sine Tarnkappen verborgen ligen vant ### dar in slovf er vil schiere do was er niemen bechant
###### 430 | ### Er ilte hin widere do vant er rechen vil ### da div chvneginne teilte ir hohen spil ### dar gi er tovgenliche von listen daz geschach ### alle di da waren daz in da niemen ensach
| ### Der rinch der was beceiget daz spil solde geschen ### vor manigem chvnen rechen di daz solden sehen ### mer danne sibenhvndert di sah man waffen tragen ### swem an dem spil gelvnge daz <erz> di helden solde sagen
###### 432 | ### Do was chomen brvnnhilt gewaffent man di vant ### sam ob si solde striten vmb elliv chvniges lant ### ia trvch si ob den siden vil manigen goldes zein ### ir minnechliche <varwe> dar vnder vil herliche schein
###### 433 | ### Do chom ir gesinde di trvgen dar ce hant ### von al rotem golde einn schildes rant ### mit stahele herte spangen vil michel vnt breit ### dar vnder spilen wolde div minnechlichiv meit
| ### Der vrowen schilt vezel ein edel porte was ### dar vffe lagen steine grvne sam ein gras ### der lvhte maniger hande mit schine wider daz golt ### er mvste wesen vil chvne dem div vrowe wrde holt
###### 435 | ### <Der> schilt was vnderbvkeln als vns daz ist gesaget ### wol drier spannen diche den solde tragen div maget ### von stahel vnt ovch von golde rich er was genvch ### den ir chamærære selbe vierde chvme trvch
| ### <Also> der starche hagene den schilt dar tragen sach ### mit grimmigem mvte der helt von Tronege sprach ### wa nv chvnich Gvnther wie vliese wir den lip ### der ir da gert ce minnen div ist des tivels wip
###### 437 | ### Ver nemt noch von ir wæte der hæte si genvch ### von Azagovch der siden einen waffen roch si trvch ### edel vnt riche ab des varwe schein ### von der chvneginne vil manich herlicher stein
| ### Do trvch man der vrowen vil swære vnd groz ### einen ger vil scharpfen den si alle cite schoz ### starch vnt vngefvge michel vnt breit ### der ce sinen ecken vil harte vreislichen sneit [310a]
###### 439 | ### Von des geres swere horet wnder sagen ### wol vierdehalbiv messe was dar zv geslagen ### den trvgen chvme drie brvnhilde man ### Gvnther der edele vil harte sorgen began
###### 440 | ### Er dahte in sinem mvte waz sol diz wesen ### der tivel vz der helle wi chvnd er da vor genesen ### wer ich ce bvrgenden mit dem lebene min ### si mvste hie lange vri vor miner minne sin
| ### Do sprach hagen brvder der chvene Danchwart ### mich riwet innechlichen disiv hove vart ### nv hiezen wir ie rechken wi verliese wir den lip ### svln vns in disen landen nv vberwinden div wip
###### 442 | ### Mich mvet daz harte sere daz ich chom in diz lant ### vnt hæte min brvder Hagene sin waffen an der hant ### vnt ovch ich daz mine so mohten sampfte gan ### mit ir vebermvete alle Prvnnhilde man
###### 443 | ### Daz wizzet sicherlichen si soldenz wol bewarn ### vnt hæt ich tvsent eide ce einem vride gesworn ### ê daz ich sterben sæhe den lieben herren min ### ia mvese den lip verliesen daz vil schone magedin
###### 444 | ### Wir solden vngefangen wol rvomen diz lant ### sprach do sin brvoder Hagene vnt heten wir daz gewant ### des wir ce der not bedvrffen vnt ovch div swert vil gvt ### so wrde wol gesenpftet der <starchen> vrowen vber mvt
| ### Wol hort div maget edele waz der dægen sprach ### mit smilendem munde si veber ahsel sach ### nv er dvnche <si> so chvene so traget in ir gewant ### ir vil scharpffen waffen gebet den recken an di hant
###### 446 | ### Do si div swert gewnnen also div maget gebot ### der vil chvne Danchwart vor vrevden wart vil rot ### nv spilen swes si wellen sprah der vil snelle man ### Gvnther ist vmbetwngen sit daz wir vnser waffen han
| ### Div Prvnnhilde sterche vil grozliche schein ### man trvch ir zv dem ringe einen swæren stein ### groz vnt vngefvge vil michel vnt <wêl> ### in trvgen chvme zwelfe helde chvne vnt snel
###### 448 | ### Den warf si zallen ziten do si den ger vershoz ### der bvrgenære sorge wrden harte groz ### waffen do sprach Hagene waz hat <der kvnich> ce trvt ### ia sol si in der helle sin des vebeln tivels brvt
| ### An vil wizzen armen si di ermel want ### si begonde vazzen den schilt an der hant ### den ger si hoch zvchte do giench iz an den [310b] strit ### Gvnther vnt Sifrit di vorhten Prvnnhilde nit
###### 450 | ### Vnt wære im Sifrit niht ce helffe chomen ### so hete si dem chvnige sinen lip benomen ### er gie dar tovgenliche vnt rvrt im sine hant ### Gvnther sine liste vil <sorchenlich> ervant
###### 451 | ### Waz hat mich gervret dahte der chvne man ### do sach er allenthalben vnt vant da niemen stan ### er sprach ich pinz Sifrit der liebe vrivnt din ### vor der chveneginne soltv gar an angest sin
###### 452 | ### <Den> shilt gip mir von hende vnt laze mich den tragen ### vnt merche rehte waz dv mich hores sagen ### nv hab dv di gebære div werch wil ich began ### do er in reht erchande ez was im liebe getan
###### 453 | ### Nv hil dv mine liste dine soltv niemen sagen ### so mach div chvneginne vil lvecel iht beiagen ### an dir deheines rvomes des si doh willen hat ### nv sihtv wi div vrowe vor dir vnsorchlichen stat
| ### Do shoz vil chrepftechliche div herlichiv meit ### vf einen schilt niwen michel vnt breit ### den trvch an siner hende daz sigelinde chint ### daz fiwer spranch von stahele als ez wæte der wint
###### 455 | ### Des starchen geres snide al dvrch den schilt gebrach ### daz man di fiwer lovgen vz den ringen sach ### des shvzzes beide strvochten di crepftigen man ### wan div Tarnkappe si wæren tote da bestan
###### 456 | ### Sifride dem vil chvenen von munde brast daz plvt ### vil balde spranch er widere do nam der helt gvt ### den ger den si <geshozzen> hæte dem helde dvrch den rant ### den frvmte ir do hin widere des starchen Sifrides hant
###### 457 | ### Er dahte ich wil niht schiezen daz schone magedin ### er cherte des geres snide hinder den rvcke sin ### mit der gerstangen er shoz vf ir gewant ### daz <ez> erchlanch vil lvote von siner ellenthaften hant
###### 458 | ### <Daz> fiwr stovp vz ringen alsam ez tribe der wint ### den shuz den shoz mit ellen daz Sigmvndes chint ### sine moht mit ir crefpten des shvzes niht gestan ### ezen hæte der chvnich Gvnther triwen niemer getan
| ### Prvnnhilt div schone vil balde si vf gespranch ### Gvnther ritter edele des shvzzes habe danch ### si want er hetez mit siner chrapft getan ### ir was dar nach geslichen ein verre crehftiger man
###### 460 | ### Do gie si hin vil balde vil zornech was ir mvt ### den stein hvop vil hohe div edel magt gvt ### si swanch in crepftechliche vil verre von der hant ### do spranch <si> nach dem wrffe ia er clanch ir allez ir gewant
| ### Der stein der was gevallen wol zwelf [311a] clafter dan ### den wrf den brach mit sprvnge div maget wol getan ### dar gie der herre Sifrit da der stein gelach ### Gvnther in do wegte der helt in werffene pfalch
###### 462 | ### Sifrit der <was> chvne vil crepftech vnt vil lanch ### den stein den warf er verrer dar zv er witer spranch ### von sinen schonen listen er hete crapft genvch ### daz er mit dem sprvnge den chvnich Gvnthere <doh> truch
| ### Der sprvnch der was ergangen der stein der was gelegen ### do sach man ander niemen wan Gvnther den degen ### Prvnnhilt div schone div wart in zorne rot ### Sifrit hæte geverret des chvnich Gvntheres tot
| ### Zv zir ingesinde einteil si lvte sprach ### do si <Gvntheren> cent des ringes wol gesvnden sach ### vil balde chvmt her naher ir mage vnt mine man ### ir svlt dem chvnige Gvnther alle wesen vndertan
###### 465 | ### Do leiten di vil chivnen div waffen von der hant ### si bvten sich ce fvzen vz bvrgvnden lant ### Gvnther dem richen vil manich chvene man ### si wanten daz er hæte div spil mit siner crapf getan
###### 466 | ### Er grvztes minnechliche ia was er tvgende rich ### do nam in bi der hende div magt lobelich ### si er lovbte im daz er da solde haben gewalt ### des frevte sich do Hagene der dægen chvne vnt balt
###### 467 | ### Si bat den ritter edele mit ir dannen gan ### in den palas witen also daz wart getan ### do er bot man ez den recken mit dienste baz ### Danchwart vnt Hagene di mvsenz lazen ane haz
###### 468 | ### Sifrit der snelle wise was genvch ### sine Tarenkappen er abe behalten trvch ### do gie er hine wider da manich vrowe saz ### er sprach zv dem chvnige vnt tet vil wisliche daz
###### 469 | ### Wes <peitet> ir min herre wan beginnet ir der spil ### der iv div chvneginne teilet also vil ### vnt lat vns balde schowen wi div sin getan ### sam ers niht en wesse gebarte der listege man
| ### Do sprach div chvniginne wi ist daz geschen ### daz ir habt her Sifrit der spil niht gesehen ### div hie hat er rvngen div Gvntheres hant ### des antwrte in Hagene vzer bvrgvnden lant
###### 471 | ### Er sprach da hete ir vns vrowe betrivbet den mvt ### do was bi dem scheffe Sifrit der helt gvt ### do der vogt von rine div spil iv an gewan ### des ist ez im vnchvnde sprach der Gvntheres man [311b]
| ### Do wol mich dirre mære sprach Sifrit <der> dægen ### daz iwer hochvart ist also hie gelægen ### daz iemen lebet der iwer meister mvege sin ### nvo svlt ir magt edele vns hinnen volgen an den rin
###### 473 | ### Do sprach div wolgetane des en mach niht ergan ### ez <mivezen> ê bevinden mage vnt mine man ### iane mag ich also lihte gervmen minvo lant ### di mine besten frivnde werden ê besant
| ### Do hiez si boten riten allenthalben dan ### si besande ir vrivnde mage vnd man ### di bat si ce Isensteine chomen vnerwant ### vnt hiez in allen gæben rich vnt herlich gewant
###### 475 | ### Si ritten tægeliche spate vnt vrv ### der Prvnnhilde <bverge> scharhaft zv ### iara ia sprach hagene waz haben wir getan ### wirr ebeiten hie vil vebele der schonen Prvnnhilde man
###### 476 | ### So si nv mit ir chrepfte choment in daz lant ### der chvneginne wille ist vnsvnbechant ### waz ob si also zvrnet daz wir sin verlorn ### so ist vns div magt edele ce grozzen sorgen geborn
| ### Do sprach der starche Sifrit daz sol ich vnder sten ### des ir da habt sorge des laz ich niht ergen ### ich sol iv helffe bringen her in diz lant ### vil erwelten rechen di iv noch nie wrden bechant
###### 478 | ### Ir svlt nach mir niht vragen ich wil hinnen varn ### got <mvez> iwer ere di zit wol bewarn ### ich chvm schiere <wider> vnt bringe tvsent man ### der aller besten dægene der ich <ie> chvende gewan
###### 479 | ### <· one> sit <et> niht ce lange sprach der chvenich do ### wir sin iwerr helffe vil pillichen vro ### er sprach ich chvm wider in vil chvrcen tagen ### daz ir mich habt gesendet daz svlt ir Prvnnhilde sagen

<<< Übersicht <<< vorige Seite nächste Seite >>>